@@ -2,8 +2,8 @@
 
 use strict;
 use warnings;
-use oEdtk::Config	qw(config_read);
-use oEdtk::DBAdmin	qw(db_connect);
+use oEdtk::Config		qw(config_read);
+use oEdtk::DBAdmin		qw(db_connect);
 use oEdtk::Messenger	qw(oe_send_mail);
 
 print "Usage: $0 < |COMSET>\n\n";
@@ -27,7 +27,7 @@ if ($opt=~/comset/i) {
 }
 
 warn "STARTING CHECK, loading config \n";
-my $cfg = config_read('MAIL', 'EDTK_DB', 'COMPO', $opt);
+my $cfg = config_read('MAIL', 'EDTK_DB', 'EDTK_STATS', 'COMPO', $opt);
 warn "\n"; 
 
 #[DEFAULT]
@@ -104,8 +104,8 @@ if ($@) {
 # CHECK DB CONNECT
 warn "\nSTART CHECK db_connect FROM oEdtk.ini...\n";
 warn "\t check DB_BAKUP : \n";
-my $dbh1 = db_connect($cfg, 'EDTK_DBI_DSN_BAK') or printf " BAD, error connecting EDTK_DBI_DSN_BAK\n";
+my $dbh1 = db_connect($cfg, 'EDTK_DSN_DBI_BAK') 	or printf " BAD, error connecting EDTK_DSN_DBI_BAK\n";
 warn "\n\t check DB_PARAM : \n";
-my $dbh2 = db_connect($cfg, 'EDTK_PARAM_DSN') or printf " BAD, error connecting EDTK_PARAM_DSN\n";
+my $dbh2 = db_connect($cfg, 'EDTK_DSN_PARAM') 	or printf " BAD, error connecting EDTK_DSN_PARAM\n";
 warn "\n\t check DB_MAIN : \n";
-my $dbh3 = db_connect($cfg, 'EDTK_DBI_DSN') or printf " BAD, error connecting EDTK_DBI_DSN\n";
+my $dbh3 = db_connect($cfg, 'EDTK_DSN_DBI')		or printf " BAD, error connecting EDTK_DSN_DBI\n";
