@@ -1,14 +1,14 @@
 #!/usr/bin/perl
 
 use oEdtk::Config	qw(config_read);
-use oEdtk::DBAdmin	qw(db_connect table_historicize);
+use oEdtk::DBAdmin	qw(db_connect historicize_table);
 use Term::ReadKey;
 use POSIX		qw(strftime);
 use warnings;
 use strict;
 
 my $cfg = config_read('EDTK_DB');
-my $dbh = db_connect($cfg, 'EDTK_DBI_DSN');
+my $dbh = db_connect($cfg, 'EDTK_DSN_DBI');
 my $wait_time =1;
 my $suffixe =strftime "%Y%m%d%H%M%S", localtime;
 $wait_time ||=500*$cfg->{'EDTK_WAITRUN'};
@@ -20,6 +20,6 @@ ReadMode('raw');
 my $key = ReadKey($wait_time);
 ReadMode ('restore');
 
-table_historicize($dbh, $cfg->{'EDTK_DBI_TRACKING'}, $suffixe);
+historicize_table($dbh, $cfg->{'EDTK_DBI_TRACKING'}, $suffixe);
 
 print "WARN : backup done for ".$cfg->{'EDTK_DBI_TRACKING'}."\n";
